<?php

    namespace KimchiAPI\Abstracts;

    abstract class RequestMethod
    {
        /**
         * The GET method requests a representation of the specified resource.
         * Requests using GET should only retrieve data.
         */
        const GET = 'GET';

        /**
         * The HEAD method asks for a response identical to a GET request, but without the response body.
         */
        const HEAD = 'HEAD';

        /**
         * The POST method submits an entity to the specified resource, often causing a change
         * in state or side effects on the server.
         */
        const POST = 'POST';

        /**
         * The PUT method replaces all current representations of the target resource with the request payload.
         */
        const PUT = 'PUT';

        /**
         * The DELETE method deletes the specified resource.
         */
        const DELETE = 'DELETE';

        /**
         * The CONNECT method establishes a tunnel to the server identified by the target resource.
         */
        const CONNECT = 'CONNECT';

        /**
         * The OPTIONS method describes the communication options for the target resource.
         */
        const OPTIONS = 'OPTIONS';

        /**
         * The TRACE method performs a message loop-back test along the path to the target resource.
         */
        const TRACE = 'TRACE';

        /**
         * The PATCH method applies partial modifications to a resource.
         */
        const PATCH = 'PATCH';

        /**
         * Hypertext Transfer Protocol (HTTP/1.1): Semantics and Content
         * Specifies GET, HEAD, POST, PUT, DELETE, CONNECT, OPTIONS, TRACE.
         */
        const RFC_7231 = [self::GET, self::HEAD, self::POST, self::PUT, self::DELETE, self::CONNECT, self::OPTIONS, self::TRACE];

        /**
         * PATCH Method for HTTP
         * Specifies PATCH.
         */
        const RFC_5789 = [self::GET, self::HEAD, self::POST, self::PUT, self::DELETE, self::CONNECT, self::OPTIONS, self::TRACE, self::PATCH];
    }